<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Interfaces\Model;

class BranchController extends Controller
{
    public function __construct()
    {
        $this->middleware('admin');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request, Model $mdl)
    {

        $branches = $mdl->model('Branch')
        ->where(['trash'=>0])
        ->select(
            'branches.*',
            \DB::raw("(SELECT SUM(amount) FROM branch_payments WHERE branch_id=branches.id AND trash=0 GROUP BY trash LIMIT 1) total_deposit"),
            \DB::raw("(SELECT SUM(amount) FROM costs WHERE branch_id=branches.id AND trash=0 GROUP BY trash LIMIT 1) total_cost")
        )
        ->get();
        return view('backend.pages.branch.index', compact('branches'));
    }
    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, Model $model)
    {
        $this->validate($request, [
            'name'=>'required|unique:branches,name'
        ]);

        $data = $request->except(['_token']);
        $model->model('Branch')->create($data);
        msg('success', 'Branch Successfully Saved');

        return redirect()->back();
    }


    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Request $request, Model $model, $id)
    {
        if($request->isMethod('POST'))
        {

            $branch = $model->model('Branch')->where(['id'=>$id]);
            if($branch->first()->name!=$request->name){
                $request->validate(['name'=>'required|unique:branches,name']);                
            }

            // UPDATE MODEL
            $data = $request->except('_token');
            $branch->update($data);

            // SET FALSE MASSAGE
            msg('success', 'Branch Successfully Updated');
            return redirect()->route('admin.branch.all');
        }
        $edit = $model->model('Branch')->where(['id'=>$id])->first();
        return view('backend.pages.branch.index', compact('edit'));
    }

    /**
     * Display Trash List of the Branch.
     *
     * @return \Illuminate\Http\Response
     */
    public function trash_list(Model $mdl, $id=null)
    {
        $branches = $mdl->model('Branch')
                  ->where(['trash'=>1])
                  ->get();
        return view('backend.pages.branch.trash', compact('branches'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function trash(Model $model, $id=null)
    {
        $model->model('Branch')->where(['id'=>$id])->update(['trash'=>1]);
        msg('success', 'Branch Status Successfully Updated');
        return redirect()->route('admin.branch.all');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete(Model $model, $id=null)
    {
        $model->model('Branch')->where(['id'=>$id])->delete();
        msg('warning', 'Branch Permanently Deleted!!');
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function back(Model $model, $id=null)
    {
        $model->model('Branch')->where(['id'=>$id])->update(['trash'=>0]);
        msg('success', 'Branch Successfully Restored');
        return redirect()->back();
    }



    /*
    * *********************************
    * BRACH WISE PAYMENT
    * *********************************
    */
    public function payment(Request $request, Model $mdl)
    {
        $where[] = ['trash', 0];

        if($request->search && is_array($request->search)){
            foreach($request->search as $key=>$value){
                if($value!=''){
                    if($key=='from')
                     $where[] = ['date', '>=', $value];
                    else if($key=='to')
                     $where[] = ['date', '<=', $value];
                    else
                     $where[] = [$key, $value];
                }
            }
        }

        if(admin()->type!='superadmin'){
            $where[] = ['branch_id', admin()->branch_id];            
        }

        $all_payments = $mdl->model('BranchPayment')->where($where)->get();

        return view('backend.pages.branch.payment', compact('all_payments'));
    }


    public function paymentStore(Request $request, Model $mdl)
    {
        if($request->isMethod('POST')){
            $data            = $request->except(['_token']);
            $data['date']    = date('Y-m-d');
            $data['user_id'] = admin()->id;

            $request->validate([
                'branch_id'=>'required',
                'amount'=>'required'
            ]);

            $mdl->model('BranchPayment')->create($data);
            msg('success', 'Payment Successfully Submited');

        }
        return redirect()->back();
    }

    
    public function paymentEdit(Request $request, Model $mdl, $id)
    {
        $edit = $mdl->model('BranchPayment')->where(['id'=>$id])->first();
        return view('backend.pages.branch.payment', compact('edit'));
    }

    
    public function paymentUpdate(Request $request, Model $mdl, $id)
    {
        $data = $request->except(['_token']);
        $mdl->model('BranchPayment')->where(['id'=>$id])->update($data);
        msg('success', 'Payment Successfully Updated');
        return redirect()->route('admin.branch.payment');
    }

    
    public function paymentDelete(Request $request, Model $mdl, $id)
    {
        $mdl->model('BranchPayment')->where(['id'=>$id])->update(['trash'=>1]);
        msg('success', 'Payment Successfully Deleted');
        return redirect()->route('admin.branch.payment');
    }
}
