<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Interfaces\Model;

class CareerController extends Controller
{
    public function __construct(){
        $this->middleware('admin');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request, Model $mdl)
    {
        $where = [];
        $careers = $mdl->model('Career')->where($where)->get();
        
        return view('backend.pages.career.index', compact('careers'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('backend.pages.career.add');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, Model $mdl)
    {
        $data = $request->except(['_token']);
        $this->validate($request, ['title'=>'required']);
        $mdl->model('Career')->create($data);

        msg('success', 'Career Object Successfully Saved');
        return redirect()->route('admin.career.all');
    }


    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id, Model $mdl)
    {
        $edit = $mdl->model('Career')->where(['id'=>$id])->first();
        return view('backend.pages.career.edit', compact('edit'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Model $mdl, $id)
    {
        $data = $request->except(['_token']);
        $mdl->model('Career')->where(['id'=>$id])->update($data);
        msg('success', 'Successfully Updated');
        return redirect()->route('admin.career.all');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Model $mdl, $id)
    {
        $mdl->model('Career')->where(['id'=>$id])->delete();
        msg('success', 'Career Object Successfully Deleted');
        return redirect()->route('admin.career.all');
    }
}