<?php

namespace App\Http\Controllers\Backend\Dev;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Interfaces\Model;

class ActionMenuController extends Controller
{
    public function __construct()
    {
        //$this->middleware('admin');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Model $mdl)
    {
        $action_menus   = $mdl->model('ActionMenu')->where(['trash'=>0])->with(['getMenu', 'getSubMenu'])->orderBy('id', 'DESC')->get();
        $menus          = $mdl->model('Menu')->where(['trash'=>0])->orderBy('id', 'DESC')->get();

        return view('backend.pages.dev.action_menu', compact('action_menus', 'menus'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, Model $mdl)
    {
        $this->validate($request, [
            'name_bn'       => 'required',
            'name_en'       => 'required',
            'menu_id'       => 'required',
            'route_name'    => 'required',
            'url'           => 'required',
        ]);

        $data = $request->except(['_token']);
        $mdl->model('ActionMenu')->create($data);
        msg('success', 'Action-Menu Successfully Saved');

        return redirect()->back();
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Request $request, Model $mdl, $id)
    {
        $edit = $mdl->model('ActionMenu')->where(['id'=>$id])->first();

        if($request->isMethod('POST'))
        {
            $this->validate($request, [
                'name_bn'       => 'required',
                'name_en'       => 'required',
                'menu_id'       => 'required',
                'route_name'    => 'required',
                'url'           => 'required',
            ]);

            $data = $request->except('_token');
            $mdl->model('ActionMenu')->where(['id'=>$id])->update($data);

            msg('success', 'Action-Menu Successfully Updated');
            return redirect()->route('dev.action_menu');
        }

        $menus        = $mdl->model('Menu')->where(['trash'=>0])->orderBy('id', 'DESC')->get();
        $action_menus = $mdl->model('SubMenu')->where(['trash'=>0, 'menu_id'=>$edit->menu_id])->orderBy('id', 'DESC')->get();
        return view('backend.pages.dev.action_menu', compact('edit', 'menus', 'action_menus'));
    }

    /**
     * Display Trash List of the Menu.
     *
     * @return \Illuminate\Http\Response
     */
    public function trash_list(Model $mdl, $id=null)
    {
        $action_menus = $mdl->model('ActionMenu')
                  ->where(['trash'=>1])
                  ->with(['getMenu'])
                  ->orderBy('id', 'DESC')->get();
        return view('backend.pages.dev.action_menu_trash_list', compact('action_menus'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function trash(Model $mdl, $id=null)
    {
        $mdl->model('ActionMenu')->where(['id'=>$id])->update(['trash'=>1]);
        msg('success', 'Menu Status Successfully Updated');
        return redirect()->route('dev.action_menu');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete(Model $mdl, $id=null)
    {
        $mdl->model('ActionMenu')->where(['id'=>$id])->delete();
        msg('warning', 'Menu Permanently Deleted!!');
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function back(Model $mdl, $id=null)
    {
        $mdl->model('ActionMenu')->where(['id'=>$id])->update(['trash'=>0]);
        msg('success', 'Menu Successfully Restored');
        return redirect()->back();
    }
}
