<?php

namespace App\Http\Controllers\Backend\Dev;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Interfaces\Model;

class MenuController extends Controller
{
    public function __construct()
    {
        //$this->middleware('admin');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Model $mdl)
    {
        $menus = $mdl->model('Menu')->where(['trash'=>0])->orderBy('id', 'DESC')->get();
        return view('backend.pages.dev.menu', compact('menus'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, Model $mdl)
    {
        $this->validate($request, [
            'name_bn'=>'required|unique:menus,name_bn',
            'name_en'=>'required|unique:menus,name_en',
        ]);

        $data = $request->except(['_token']);
        $mdl->model('Menu')->create($data);
        msg('success', 'Menu Successfully Saved');

        return redirect()->back();
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Request $request, Model $mdl, $id)
    {
        $menus = $mdl->model('SubMenu')->where(['trash'=>0])->get();
        $edit = $mdl->model('Menu')->where(['id'=>$id])->first();

        if($request->isMethod('POST'))
        {
            if($edit->name_bn!=$request->name_bn){
                $this->validate($request, [
                    'name_bn'=>'required|unique:menus,name_bn',
                ]);
            }
            if($edit->name_en!=$request->name_en){
                $this->validate($request, [
                    'name_en'=>'required|unique:menus,name_en',
                ]);
            }

            $data = $request->except('_token');
            $mdl->model('Menu')->where(['id'=>$id])->update($data);

            msg('success', 'Menu Successfully Updated');
            return redirect()->route('dev.menu');
        }

        return view('backend.pages.dev.menu', compact('edit', 'menus'));
    }

    /**
     * Display Trash List of the Menu.
     *
     * @return \Illuminate\Http\Response
     */
    public function trash_list(Model $mdl, $id=null)
    {
        $menus = $mdl->model('Menu')
                  ->where(['trash'=>1])
                  ->orderBy('id', 'DESC')->get();
        return view('backend.pages.dev.menu_trash_list', compact('menus'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function trash(Model $mdl, $id=null)
    {
        // Update Menu
        $mdl->model('Menu')->where(['id'=>$id])->update(['trash'=>1]);

        // Update Sub-Menu
        if($mdl->model('SubMenu')->where(['menu_id'=>$id])->exists())
            $mdl->model('SubMenu')->where(['menu_id'=>$id])->update(['trash'=>1]);

        // Update Action-Menu
        if($mdl->model('ActionMenu')->where(['menu_id'=>$id])->exists())
            $mdl->model('ActionMenu')->where(['menu_id'=>$id])->update(['trash'=>1]);

        msg('success', 'Menu Status Successfully Updated');
        return redirect()->route('dev.menu');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete(Model $mdl, $id=null)
    {
        $mdl->model('Menu')->where(['id'=>$id])->delete();


        // Delete Sub-Menu
        if($mdl->model('SubMenu')->where(['menu_id'=>$id])->exists())
            $mdl->model('SubMenu')->where(['menu_id'=>$id])->delete();

        // Delete Action-Menu
        if($mdl->model('ActionMenu')->where(['menu_id'=>$id])->exists())
            $mdl->model('ActionMenu')->where(['menu_id'=>$id])->delete();

        msg('warning', 'Menu Permanently Deleted!!');
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function back(Model $mdl, $id=null)
    {
        $mdl->model('Menu')->where(['id'=>$id])->update(['trash'=>0]);
        msg('success', 'Menu Successfully Restored');
        return redirect()->back();
    }



    // All Menu Sorting 
    public function sorting(Request $request, Model $mdl)
    {
        $menus = $mdl->model('Menu')->where(['trash'=>0])->with(['submenu'])->orderBy('position', 'ASC')->get();
        return view('backend.pages.dev.menu_sorting', compact('menus'));
    } 
}
