<?php

namespace App\Http\Controllers\Backend\Dev;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Interfaces\Model;
use App\Models\SubMenu;

class SubMenuController extends Controller
{
    public function __construct()
    {
        //$this->middleware('admin');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Model $mdl)
    {
        $sub_menus  = $mdl->model('SubMenu')->where(['trash'=>0])->with(['getMenu'])->orderBy('position', 'ASC')->get();
        $menus      = $mdl->model('Menu')->where(['trash'=>0])->orderBy('position', 'ASC')->get();

        return view('backend.pages.dev.sub_menu', compact('sub_menus', 'menus'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, Model $mdl)
    {
        $this->validate($request, [
            'name_bn'   =>'required',
            'name_en'   =>'required',
            'menu_id'   =>'required',
            'route_name'=>'required',
            'url'       =>'required',
        ]);

        $data = $request->except(['_token']);
        $mdl->model('SubMenu')->create($data);
        msg('success', 'Menu Successfully Saved');

        return redirect()->back();
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Request $request, Model $mdl, $id)
    {
        $sub_menus = $mdl->model('SubMenu')->where(['trash'=>0])->get();
        $menus     = $mdl->model('Menu')->where(['trash'=>0])->orderBy('id', 'DESC')->get();
        $edit      = $mdl->model('SubMenu')->where(['id'=>$id])->first();

        if($request->isMethod('POST'))
        {
            $this->validate($request, [
                'name_bn'   =>'required',
                'name_en'   =>'required',
                'menu_id'   =>'required',
                'route_name'=>'required',
                'url'       =>'required',
            ]);

            $data = $request->except('_token');
            $mdl->model('SubMenu')->where(['id'=>$id])->update($data);

            msg('success', 'Menu Successfully Updated');
            return redirect()->route('dev.sub_menu');
        }

        return view('backend.pages.dev.sub_menu', compact('edit', 'sub_menus', 'menus'));
    }

    /**
     * Display Trash List of the Menu.
     *
     * @return \Illuminate\Http\Response
     */
    public function trash_list(Model $mdl, $id=null)
    {
        $sub_menus = $mdl->model('SubMenu')
                  ->where(['trash'=>1])
                  ->with(['getMenu'])
                  ->orderBy('id', 'DESC')->get();
        return view('backend.pages.dev.sub_menu_trash_list', compact('sub_menus'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function trash(Model $mdl, $id=null)
    {
        $mdl->model('SubMenu')->where(['id'=>$id])->update(['trash'=>1]);
        msg('success', 'Menu Status Successfully Updated');
        return redirect()->route('dev.sub_menu');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function delete(Model $mdl, $id=null)
    {
        $mdl->model('SubMenu')->where(['id'=>$id])->delete();
        msg('warning', 'Menu Permanently Deleted!!');
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function back(Model $mdl, $id=null)
    {
        $mdl->model('SubMenu')->where(['id'=>$id])->update(['trash'=>0]);
        msg('success', 'Menu Successfully Restored');
        return redirect()->back();
    }
}
