<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Interfaces\Model;

class GoalPurposeController extends Controller
{
    public function __construct(){
        $this->middleware('admin');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request, Model $mdl)
    {
        $where = [];
        $goals = $mdl->model('GoalPurpose')->where($where)->orderBy('position', 'ASC')->get();
        
        return view('backend.pages.goal.index', compact('goals'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('backend.pages.goal.add');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, Model $mdl)
    {
        $data = $request->except(['_token']);
        $this->validate($request, ['goal'=>'required']);
        $mdl->model('GoalPurpose')->create($data);

        msg('success', 'Package Width Successfully Saved');
        return redirect()->route('admin.goal.all');
    }


    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id, Model $mdl)
    {
        $edit = $mdl->model('GoalPurpose')->where(['id'=>$id])->first();
        return view('backend.pages.goal.edit', compact('edit'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Model $mdl, $id)
    {
        $data = $request->except(['_token']);
        $mdl->model('GoalPurpose')->where(['id'=>$id])->update($data);
        msg('success', 'Successfully Updated');
        return redirect()->route('admin.goal.all');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function toTrash(Request $request, Model $mdl, $id)
    {
        $data = $request->except(['_token']);
        $mdl->model('GoalPurpose')->where(['id'=>$id])->delete();
        msg('success', 'Successfully Deleted');
        return redirect()->route('admin.goal.all');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function backToTrash(Request $request, Model $mdl, $id)
    {
        $data = $request->except(['_token']);
        $mdl->model('GoalPurpose')->where(['id'=>$id])->update(['trash'=>0]);
        msg('success', 'Successfully Restored');
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function SortGoal(Request $request, Model $mdl, $id_position)
    {
        $id_position = json_decode($id_position);
        $position    = false;
        
        foreach($id_position as $id => $pos){
            if($mdl->model('GoalPurpose')->where(['id'=>$id])->update(['position'=>$pos]))
            {
                $status = true;
            }else{
                $status = false;
            }
        }

        return $status;
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function trashList(Request $request, Model $mdl)
    {
        $where = [['trash', 1]];
        if($request->isMethod('POST')){
            if($request->search && is_array($request->search)){
                foreach ($request->search as $key => $value) {
                    if($value != ''){
                        $where[] = [
                            $key, 'LIKE', "%{$value}%"
                        ];
                    }
                }
            }
            $user = $mdl->model('GoalPurpose')->where($where);
            $data = [
                "totalItem" => $user->count(),
                "data"      => $user->skip($request->skip)->take($request->take)->orderBy('id', 'DESC')->get(),
                "request"   => $request->all()
            ];
            return response()->json($data);
        }
        
        return view('backend.pages.goal.trash_list');
    }
}