<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Interfaces\Model;

class MemberController extends Controller
{
    public function __construct(){
        $this->middleware('admin');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request, Model $mdl)
    {
        $where = [];
        if($request->search && is_array($request->search)){
            foreach($request->search as $key=>$value){
                if($value!='' && $key!='name'){
                    $where[] = [$key, '=', $value];
                }
                if($value!='' && $key=='name'){
                    $where[] = ['name_en', 'LIKE', "%{$value}%"];
                }
            }
        }


        $members = $mdl->model('Registration')->where($where)->get();
        return view('backend.pages.member.all', compact('members'));
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function profile(Request $request, Model $mdl, $id)
    {
        $member = $mdl->model('Registration')->where(['id'=>$id])->first();
        return view('backend.pages.member.profile', compact('member'));
    }

    /**
     * Update the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function statusUpdate(Request $request, Model $mdl, $id)
    {
        $member = $mdl->model('Registration')->where(['id'=>$id]);
        if(!$member->get()->isEmpty() && $request->status){
           $member->update(['status'=>$request->status]);
           msg('success', 'Member status Successfully Updated');
        }
        else{
           msg('warning', 'Something is wrong!! Please try again..');
        }
        return redirect()->route('admin.member.all');
    }

    /**
     * Show edit form of the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Request $request, Model $mdl, $id)
    {
        $member = $mdl->model('Registration')->where(['id'=>$id])->first();
        return view('backend.pages.member.edit', compact('member'));
    }

    /**
     * Update Data of the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Model $mdl, $id)
    {
           
        $member = $mdl->model('Registration')->where(['id'=>$id]);
        if(!$member->get()->isEmpty())
        {
            $data = $request->except(['_token', 'child_names', 'child_ages']);
            $children = [];
            if(is_array($request->child_ages) && is_array($request->child_names)){
                foreach($request->child_names as $key=>$child_name){
                    if($child_name!=''){
                        $children[]=[
                            'name'=>$request->child_names[$key],
                            'age'=>$request->child_ages[$key],
                        ];
                    }
                }
            }
            $data['children'] = json_encode($children);


            $old_member = $member->first();
            if($request->enclosed_documents)
            {

                $old_files = json_decode($old_member->enclosed_documents, true);
                if($old_files){
                    foreach($old_files as $file){
                        if(file_exists($file))
                            unlink($file);
                    }
                }


                $files = $request->file('enclosed_documents');
                $documents = [];
                foreach($files as $key=>$file){
                    $extension = $file->getClientOriginalExtension();
                    $name = (time()+$key).".".$extension;
                    $path = "public/images/documents/";
                    $file->move($path, $name);
                    $documents[] = $path.$name;
                }
                $data['enclosed_documents'] = json_encode($documents); 
            }

            if($request->signeture_of_application)
            {
                if(file_exists($old_member->signeture_of_application)){
                    unlink($old_member->signeture_of_application);
                }
                $extension = $request->signeture_of_application->getClientOriginalExtension();
                $name = (time()).".".$extension;
                $path = "public/images/signature/";
                $request->signeture_of_application->move($path, $name);
                $data['signeture_of_application'] = $path.$name;
            }

            $member->update($data);
            msg('success', 'Data Successfully Updated');
            return redirect()->route('admin.member.edit', $id);
        }
        else{
           msg('warning', 'Something is wrong!! Please try again..');
        }
        return redirect()->route('admin.member.all');
    }

}
