<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Interfaces\Model;

class NewsLetterController extends Controller
{
    public function __construct(){
        $this->middleware('admin');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Model $mdl)
    {
        $newsletters = $mdl->model('NewsLetter')->get();
        return view('backend.pages.news_letter.all', compact('newsletters'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Model $md)
    {
        return view('backend.pages.news_letter.add');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request,  Model $md)
    {
        $request->validate([
            'title' => 'required',
        ]);

        $data = $request->except(['_token', 'cover_photo']);

        if($request->cover_photo){
            $extension = $request->cover_photo->getClientOriginalExtension();
            $name = (time()).".".$extension;
            $path = "public/images/news_letter/";
            $request->cover_photo->move($path, $name);
            $data['cover_photo'] = $path.$name;
        }

        $md->model("NewsLetter")->create($data);
        msg('success', 'News Letter Successfully Saved');
        return redirect()->route('admin.newsletter.all');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Model $mdl, $id)
    {
        $newsletter = $mdl->model("NewsLetter")->where(['id'=>$id])->first();
        return view('backend.pages.news_letter.edit', compact('newsletter'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Model $mdl, $id)
    {
        $request->validate(['title' => 'required']);
        $data = $request->except(['_token', 'cover_photo']);

        $newsletter = $mdl->model("NewsLetter")->where(['id'=>$id]);
        if($request->cover_photo)
        {
            $old_file = $newsletter->first()->cover_photo;
            if(file_exists($old_file)){
                unlink($old_file);
            }
            // New Cover Photo
            $extension = $request->cover_photo->getClientOriginalExtension();
            $name = (time()).".".$extension;
            $path = "public/images/news_letter/";
            $request->cover_photo->move($path, $name);
            $data['cover_photo'] = $path.$name;
        }

        $newsletter->update($data);
        msg('success', 'News Letter Successfully Saved');
        return redirect()->route('admin.newsletter.all');
    }

    /**
     * View the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function view(Model $mdl, $id)
    {
        $newsletter = $mdl->model("NewsLetter")->where(['id'=>$id])->first();
        return view('backend.pages.news_letter.view', compact('newsletter'));
    }

    /**
     * Destroy the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Model $mdl, $id)
    {
        $newsletter = $mdl->model("NewsLetter")->where(['id'=>$id]);

        $old_file = $newsletter->first()->cover_photo;
        if(file_exists($old_file)){
            unlink($old_file);
        }
        $newsletter->delete();
        return redirect()->route('admin.newsletter.all');
    }
}
