<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Interfaces\Model;

class SliderController extends Controller
{
    public function __construct()
    {
        $this->middleware('admin');
    }
    
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Model $model)
    {
        $cond = [['trash', '=', 0]];
        if(isset($_GET['search']))
        {
            foreach ($_GET['search'] as $key => $value) {
                if(!empty($value))
                {
                    $cond[] = [$key, '=', $value];
                }
            }
        }
        
        $sliders = $model->model('Slider')->where($cond)->orderBy('position', 'asc')->get();

        $sliders_for_filter = $model->model('Slider')->where(['trash'=>0])->orderBy('position', 'asc')->get();
        return view('backend.pages.slider.index', compact('sliders', 'sliders_for_filter'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('backend.pages.slider.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, Model $model)
    {
        $this->validate($request, [
            'img'=>'required'
        ]);

        $data = [
            'title'       => $request->title,
            'subtitle'    => $request->subtitle,
            'link'        => $request->link,
            'anchor_text' => $request->anchor_text
        ];

        /*img upload processing start*/
        if(!is_null($request->img))
        {
            $extension = $request->img->getClientOriginalExtension();
            $name = (time()).".".$extension;
            $path = "public/images/gallery/";
            $request->img->move($path, $name);
            $data['img_path'] =  $path.$name;
        }


        /*img upload processing end*/
        if($model->model('Slider')->create($data)){
            msg('success', 'Slider Successfully Saved');
        }else{
            msg('warning', 'Slider Not Saved');
        }

        return redirect()->back();
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id, Model $model)
    {
        $slider = $model->model('Slider')->where(['id'=>$id, 'trash'=>0])->first();
        return view('backend.pages.slider.edit', compact('slider'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id, Model $model)
    {
        $old_data = $model->model('Slider')->where(['id'=>$id, 'trash'=>0])->first();
        
        $data = $request->except(['_token', 'old_path', 'img']);

        if($request->img){
            if(file_exists($old_data->img_path)){
                unlink($old_data->img_path);
            }

            $extension = $request->img->getClientOriginalExtension();
            $name = (time()).".".$extension;
            $path = "public/images/gallery/";
            $request->img->move($path, $name);
            $data['img_path'] =  $path.$name;
        }

        $model->model('Slider')->where(['id'=>$id])->update($data);
        msg('success', 'Slider Successfully Updated');

        return redirect()->route('admin.slider.all');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id, Model $model)
    {
        $old_data = $model->model('Slider')->where(['id'=>$id, 'trash'=>0])->first();

        if($old_data){
            if(file_exists($old_data->img_path)){
                unlink($old_data->img_path);
            }
        }

        msg('success', 'Slider Successfully Deleted');
        $model->model('Slider')->where(['id'=>$id])->delete();

        return redirect()->back();
    }

    public function slider_sorting($id_position, Model $model)
    {
        $id_position = json_decode($id_position);
        $position    = false;
        
        foreach($id_position as $id => $pos){
            if($model->model('Slider')->where(['id'=>$id])->update(['position'=>$pos]))
            {
                $status = true;
            }else{
                $status = false;
            }
        }

        return $status;
    }

}