<?php

namespace App\Http\Controllers\Backend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Interfaces\Model, Hash;
use App\Interfaces\Image;

class UserController extends Controller
{
    public function __construct()
    {
        $this->middleware('admin');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request, Model $mdl)
    {
        $where[] = ['trash', 0];

        if(admin()->type!='superadmin'){
            $where[] = ['type', '!=', 'superadmin'];
        }

        if($request->isMethod('POST')){
            foreach ($request->search as $key => $value) {
                if($value!='')
                    $where[] = [$key, $value];
            }
        }


        $admins = $mdl->model('Admin')->where($where)->get();
        return view('backend.pages.users.all', compact('admins'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Model $mdl)
    {
        return view('backend.pages.users.add');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, Model $mdl, Image $img)
    {
        $request->validate([
            'name'      => 'required',
            'username'  => 'required|unique:admins,username',
            'email'     => 'required|unique:admins,email',
            'mobile'    => 'required|unique:admins,mobile',
            'type'      => 'required',
            'password'  => 'required|min:6',
            'confirm_password'  => 'required|same:password',
        ]);

        if($request->photo){
            $request->validate(['photo'=>'required|image']);
            $path = $img->file($request->photo)->resize(400)->save('public/images/admin/', time(), 70);
        }

        $data = $request->except(['_token']);
        $data['password'] = Hash::make($request->password);
        $data['img']      = ($path ?? '');
        // Insert int the Model
        $mdl->model('Admin')->create($data);

        msg('success', 'User Successfully Created');
        return redirect()->route('admin.user.all');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id, Model $mdl)
    {
        $admin = $mdl->model('Admin')->where(['id'=>$id])->first();
        return view('backend.pages.users.edit', compact('admin'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Model $mdl, Image $img, $id)
    {
        $admin  = $mdl->model('Admin')->where(['id'=>$id]);
        $niddle = $admin->first();
        $request->validate(['name' => 'required']);

        if($request->email!=$niddle->email)
            $request->validate(['email' => 'required|unique:admins,email']);
        if($request->mobile!=$niddle->mobile)
            $request->validate(['mobile' => 'required|unique:admins,mobile']);

        $data = $request->except(['_token', 'photo', 'username', 'password', 'confirm_password']);

        if($request->password){
            $request->validate([
                'password' => 'required|min:6',
                'confirm_password'  => 'required|same:password',
            ]);
            $data['password'] = Hash::make($request->password);
        }

        if($request->photo){
            $request->validate(['photo'=>'required|image']);
            $data['img'] = $img->file($request->photo)->resize(400)->delete($niddle->img)->save('public/images/admin/', time(), 70);
        }
        $admin->update($data);
        msg('success', 'Successfully Updated');
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function trash(Model $mdl, $id)
    {
        $mdl->model('Admin')->where(['id'=>$id])->update(['trash'=>1]);
        msg('success', 'Successfully Sent To Trash');
        return redirect()->back();
    }

    public function profile(Model $mdl, $user_id)
    {
        $admin = $mdl->model('Admin')->where(['id'=>$user_id])->first();
        return view('backend.pages.users.profile', compact('admin'));
    }
}
