<?php

namespace App\Http\Controllers\Fontend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Interfaces\Model, Hash;
use App\Models\User;

class RegistrationController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function form()
    {
        return view('fontend.pages.auth.registration');
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, Model $mdl)
    {
        // $request->validate([
        //     'username'=>'required|unique:users,username',
        //     'password' => 'min:6',
        //     'password_confirmation' => 'required_with:password|same:password|min:6'
        // ]);

        $validate = \Validator::make($request->all(), [
            'username' => 'required|unique:users,username',
            'password' => 'min:6',
            'password_confirmation' => 'required_with:password|same:password'
        ]);

        if ($validate->fails()) {
            return redirect()->back()->withInput()->withErrors($validate->errors());
        }


        // CREATE USER
        $user = $request->only('username');
        $user['name'] = strtoupper($request->name_en);
        $user['password'] = Hash::make($request->password);
        $user = User::create($user);


        // REGISTRATION MODEL
        $data = $request->except(['_token', 'child_names', 'child_ages', 'password_confirmation', 'password', 'username']);
        $data['user_id'] = $user->id;
        $data['name_en'] = strtoupper($request->name_en);

        $children = [];
        if ($request->child_ages && is_array($request->child_ages) && is_array($request->child_names)) {
            foreach ($request->child_names as $key => $child_name) {
                if ($child_name != '') {
                    $children[] = [
                        'name' => $request->child_names[$key],
                        'age' => $request->child_ages[$key],
                    ];
                }
            }
        }
        $data['children'] = json_encode($children);


        if ($request->enclosed_documents) {
            $files = $request->file('enclosed_documents');
            $documents = [];
            foreach ($files as $key => $file) {
                $extension = $file->getClientOriginalExtension();
                $name = (time() + $key) . "." . $extension;
                $path = "public/images/documents/";
                $file->move($path, $name);
                $documents[] = $path . $name;
            }
            $data['enclosed_documents'] = json_encode($documents);
        }

        if ($request->signeture_of_application) {
            $extension = $request->signeture_of_application->getClientOriginalExtension();
            $name = (time()) . "." . $extension;
            $path = "public/images/signature/";
            $request->signeture_of_application->move($path, $name);
            $data['signeture_of_application'] = $path . $name;
        }
        if ($request->certificate) {
            $extension = $request->certificate->getClientOriginalExtension();
            $name = (time()) . "." . $extension;
            $path = "public/images/certificate/";
            $request->certificate->move($path, $name);
            $data['certificate'] = $path . $name;
        }

        $mdl->model("Registration")->create($data);
        session()->flash('success', 'Your Application Successfully Submited');
        return redirect()->route('login', $user->username);
    }
}
