<?php

namespace App\Http\Controllers\Fontend;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Interfaces\Model, Auth;

class UserController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('fontend.pages.user.dashboard');
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function profile(Model $mdl)
    {
        $profile = $mdl->model('Registration')->where(['user_id'=>Auth::guard('web')->user()->id])->first();

        return view('fontend.pages.user.profile', compact('profile'));
    }

    public function updateProfile(Request $request, Model $mdl){

        $user = Auth::guard('web')->user();
        $registration = $mdl->model("Registration")->where(['user_id'=>$user->id]);

        // REGISTRATION MODEL
        $data = $request->except(['_token', 'child_names', 'child_ages', 'password_confirmation', 'password', 'username']);
        $data['user_id'] = $user->id;


        //
        $data['enclosed_national_id'] = $request->enclosed_national_id ? $request->enclosed_national_id : '';
        $data['enclosed_photograph'] = $request->enclosed_photograph ? $request->enclosed_photograph : '';
        $data['enclosed_diploma_certificate'] = $request->enclosed_diploma_certificate ? $request->enclosed_diploma_certificate : '';
        $data['enclosed_visiting_card'] = $request->enclosed_visiting_card ? $request->enclosed_visiting_card : '';



        $children = [];
        if($request->child_ages && is_array($request->child_ages) && is_array($request->child_names)){
            foreach($request->child_names as $key=>$child_name){
                if($child_name!=''){
                    $children[]=[
                        'name'=>$request->child_names[$key],
                        'age'=>$request->child_ages[$key],
                    ];
                }
            }
        }
        $data['children'] = json_encode($children);


        if($request->enclosed_documents){
            $old_files = json_decode($registration->first()->enclosed_documents, true);
            if($old_files){
                foreach($old_files as $file){
                    if(file_exists($file))
                        unlink($file);
                }
            }


            $files = $request->file('enclosed_documents');
            $documents = [];
            foreach($files as $key=>$file){
                $extension = $file->getClientOriginalExtension();
                $name = (time()+$key).".".$extension;
                $path = "public/images/documents/";
                $file->move($path, $name);
                $documents[] = $path.$name;
            }
            $data['enclosed_documents'] = json_encode($documents); 
        }

        if($request->signeture_of_application){

            if(file_exists($registration->first()->signeture_of_application)){
                unlink($registration->first()->signeture_of_application);
            }

            $extension = $request->signeture_of_application->getClientOriginalExtension();
            $name = (time()).".".$extension;
            $path = "public/images/signature/";
            $request->signeture_of_application->move($path, $name);
            $data['signeture_of_application'] = $path.$name;
        }

        if ($request->certificate) {
            $extension = $request->certificate->getClientOriginalExtension();
            $name = (time()) . "." . $extension;
            $path = "public/images/certificate/";
            $request->certificate->move($path, $name);
            $data['certificate'] = $path . $name;
        }

        $registration->update($data);
        $mdl->model("User")->where(['id'=>$user->id])->update(['name'=>$request->name_en]);


        session()->flash('success', 'Your Profile Successfully Updated');
        return redirect()->route('user.profile');
    }

    public function members(Request $request, Model $mdl)
    {
        $all_members = $mdl->model('Registration')->where([])->get();
        return view('fontend.pages.user.members', compact('all_members'));
    }

    public function updateProfilePic(Request $request, Model $mdl)
    {
        if($request->user_id){
            $user = $mdl->model('User')->where(['id'=>$request->user_id])->first();
            if(file_exists($user->img))
                unlink($user->img);

            $extension = $request->file->getClientOriginalExtension();
            $name = (time()).".".$extension;
            $path = "public/images/profile/";
            $request->file->move($path, $name);
            $user->update(['img'=>$path.$name]);
            return $path.$name;
        }
        return 0;
    }
}
