@extends('backend.layouts.app')
@section('title', 'Add/All Sub-Menu')

@section('content')
<div class="card">
	<div class="card-header">
		<h6>{{isset($edit) ? 'Edit' : 'Add'}} Sub-Menu</h6>
	</div>
	<div class="card-body">
		<div class="row">
			<div class="col-md-11">
				<form action="{{isset($edit) ? route('dev.sub_menu.edit', $edit->id) : route('dev.sub_menu.store')}}" method="post" enctype="multipart/form-data">
					@csrf
				    <div class="form-row">
				        <label class="col-md-2 text-right p-1"><strong>Name(En)<span class="required">*</span></strong></label>
				        <div class="form-group col-md-4 required">
				            <input type="text" name="name_en" value="{{isset($edit) ? $edit->name_en:old('name_en')}}" id="name_en" placeholder="Menu Name(En)" autocomplete="off" class="form-control @error('name_en') error @enderror" required>
				            @error('name_en') <span class="flash-text">{{$message}}</span> @enderror
				        </div>

				        <label class="col-md-2 text-right p-1"><strong>Name(Bn)<span class="required">*</span></strong></label>
				        <div class="form-group col-md-4 required">
				            <input type="text" name="name_bn" value="{{isset($edit) ? $edit->name_bn:old('name_bn')}}" id="name_bn" placeholder="Menu Name(Bn)" autocomplete="off" class="form-control @error('name_bn') error @enderror" required>
				            @error('name_bn') <span class="flash-text">{{$message}}</span> @enderror
				        </div>
				    </div>
				    <div class="form-row">
				        <label class="col-md-2 text-right p-1"><strong>Route Name<span class="required">*</span></strong></label>
				        <div class="form-group col-md-4 required">
				            <input type="text" name="route_name" value="{{isset($edit) ? $edit->route_name:old('route_name')}}" id="route_name" placeholder="Route Name" autocomplete="off" class="form-control @error('route_name') error @enderror" >
				            @error('route_name') <span class="flash-text">{{$message}}</span> @enderror
				        </div>

				        <label class="col-md-2 text-right p-1"><strong>Url<span class="required">*</span></strong></label>
				        <div class="form-group col-md-4 required">
				            <input type="text" name="url" value="{{isset($edit) ? $edit->url:old('url')}}" id="url" placeholder="Url" autocomplete="off" class="form-control @error('url') error @enderror" required>
				            @error('url') <span class="flash-text">{{$message}}</span> @enderror
				        </div>
				    </div>
				    <div class="form-row">
				        <label class="col-md-2 text-right p-1"><strong>Menu<span class="required">*</span></strong></label>
				        <div class="form-group col-md-4 required">
				        	<select name="menu_id" class="form-control @error('menu_id') error @enderror" data-value="{{isset($edit)?$edit->menu_id:old('menu_id')}}" required>
				        		<option value="">--Select A Menu--</option>
				        		@if(!empty($menus)) @foreach($menus as $row) 
				        		<option value="{{$row->id}}">{{$row->name_en}}</option>
				        		@endforeach @endif
				        	</select>
				            @error('menu_id') <span class="flash-text">{{$message}}</span> @enderror
				        </div>

				        <label class="col-md-2 text-right p-1"><strong>Icon</strong></label>
				        <div class="form-group col-md-4">
				            <input type="text" name="icon" value="{{isset($edit) ? $edit->icon:old('icon')}}" id="icon" placeholder="fa fa-icon" autocomplete="off" class="form-control" >
				        </div>
				    </div>
				    <div class="form-row">
				        <div class="form-group col-12 text-right">
				            <button type="submit" class="btn btn-success">{{isset($edit) ? 'Update' : 'Save'}}</button>
				        </div>
				    </div>
				</form>
			</div>
		</div>
	</div>
</div>
<!-- Main Section -->
@if(!isset($edit))
<div class="card mt-3">
	<div class="card-header">
		<h6 class="float-left">All Sub-Sub-Menus</h6>
		<div class="float-right">
			<a href="{{route('dev.sub_menu.trash_list')}}">Trash List</a>
		</div>
	</div>
	<div class="card-body">
		@if(!$sub_menus->isEmpty())
		<div class="table-responsive">
			<table class="table table-bordered list-table">
				<thead class="list-header">
					<tr>
						<th width="60">SL</th>
						<th width="60">Icon</th>
						<th>Name(En)</th>
						<th>Name(Bn)</th>
						<th>Menu</th>
						<th>Route Name</th>
						<th>URL</th>
						<th width="60">Action</th>
					</tr>
				</thead>
				<tbody>
					@foreach($sub_menus as $key=>$value)
					<tr>
						<td>{{++$key}}</td>
						<td><span><i class="{{$value->icon}}"></i></span></td>
						<td>{{$value->name_en}}</td>
						<td>{{$value->name_bn}}</td>
						<td>{{$value->getMenu->name_en ?? 'N/A'}}</td>
						<td>{{$value->route_name ?? "N/A"}}</td>
						<td>{{$value->url ?? "N/A"}}</td>
						<td>
							<div class="btn-group">
								<a href="{{route('dev.sub_menu.edit', $value->id)}}" class="btn btn-sml btn-success" title="Edit"><i class="fa fa-pencil-square-o"></i></a>
								<a href="{{route('dev.sub_menu.trash', $value->id)}}" class="btn btn-sml btn-danger confirmation" title="Trash"><i class="fa fa-trash-o"></i></a>
							</div>
						</td>
					</tr>
					@endforeach
				</tbody>
			</table>
		</div>
		@else
		<div class="nothing-found">
			<div>
				<h1 title="Nothing Here...">¯\_(ツ)_/¯</h1>
				<h5>Nothing Here</h5>
			</div>
		</div>
		@endif
	</div>
</div>
@endif
@endsection