@extends('backend.layouts.app')
@section('title', 'Goal & Purpose')

@section('style')
<style>
	.loader{
		width: fit-content;
		height: 100%;
		place-items: center;
		padding: 0 10px;
		display: none;
	}
	
	.loader.active{
		display: inline-grid;
	}
	.loader .spinner{
		display: inline-block;
		width: 20px;
		height: 20px;
		border-radius: 50%;
		border: 3px solid #0001;
		border-right-color: orangered;
		animation-name: spinner;
		animation-duration: 1s;
		animation-iteration-count: infinite;
		animation-timing-function: cubic-bezier(0.5, 1.11, 0.51, 1.3);
	}
	@keyframes spinner{
		0%{
			transform: rotate(0deg);
		}
		100%{
			transform: rotate(360deg);
		}
	}
	.image_upload_zone{
		display: block;
		width: 100%;
		border: 2px dashed #ddd;
		position: relative;
		padding: 40px 10px;
		margin: 25px 0;
		text-align: center;
	}
	.image_upload_zone input[type=file]{
		position: absolute;
		top: 0;
		left: 0;
		width: 100%;
		height: 100%;
		opacity: 0;
	}
	.image_upload_zone i{
		vertical-align: middle;
		border-style: none;
		font-size: 100px;
		margin: auto;
		display: block;
	}
	.image_upload_zone .text{
		text-align: center;
		font-size: 1.2rem;
	}
	.image_upload_zone .text button{
		background: #fff;
		padding: 10px 25px;
		margin: 15px 0;
		font-weight: bold;
		box-shadow: 0 1px 10px #0002;
		border: 1px solid #bcbcbc;
	}
	.image_preview_wrapper{
		margin: 15px 0;
		display: block;
		width: 100%;
	}
	.image_preview_wrapper img{
		display: block;
		max-width: 400px;
	}
	td:hover{
		cursor:move;
	}
	.coloumn{
		display: grid;
		margin: 5px 0;
	}
	.coloumn ._row.heading{
		font-weight: 600;
		background-color: #f8f8f8;
	}
	.coloumn ._row{
		display: grid;
		grid-template-columns: 80%  12% 8%;
	}
	.coloumn ._row>div{
		border: 1px solid #0001;
		margin-bottom: -1px;
		padding: 6px 10px;
		display: grid;
		align-items: center;
		pointer-events: none;
	}
	.coloumn ._row>div+div{
		margin-left: -1px;
	}
	.coloumn ._row>div.action{
		place-content: center;
		pointer-events: auto;
	}
</style>
@endsection


@section('content')
	<!-- Main Section -->
	<div class="card mt-3">
		<div class="card-header">
			<h4 class="float-left mt-1">Goal & Purpose</h4>
			<div class="loader">
				<span class="spinner"></span>
			</div>
			<div class="float-right">
				<a href="{{ route('admin.goal.add') }}" class="btn btn-success">Add New</a>
			</div>
		</div>

		<div class="card-body min75vh">

			<div class="table-responsive">
				<div class="coloumn drag-sort-enable" id="table">
					
					<div class="_row heading">
						<div>Goal & Purpose</div>
						<div></div>
						<div>Action</div>
					</div>
						
					@if(!empty($goals)) @foreach($goals as $key=>$row)
						<div class="_row slider_item" data-id="{{ $row->id }}" draggable>
							<div>{{ $row->goal }}</div>
							<div></div>
							<div class="text-center action">
								<div class="btn-group">
									<a href="{{route('admin.goal.edit', $row->id)}}" title="Edit" class="btn btn-sml btn-success">
										<i class="fa fa-pencil-square-o"></i>
									</a>
									<a href="{{route('admin.goal.totrash', $row->id)}}" class="confirmation btn btn-sml btn-danger" data-title="Are You sure Trashed This Recored ??" title="Trash">
										<i class="fa fa-trash-o"></i>
									</a>
								</div>
							</div>
						</div>
					@endforeach @endif
				</div>
			</div>
		</div>
	</div>
@endsection

@section('scripts')
<script>
	function enableDragSort(listClass) {
	  const sortableLists = document.getElementsByClassName(listClass);
	  Array.prototype.map.call(sortableLists, (list) => {enableDragList(list)});
	}
	function enableDragList(list) {
		Array.prototype.map.call(list.children, (item) => {enableDragItem(item)});
	}
	function enableDragItem(item) {
	  item.setAttribute('draggable', true)
	  item.ondrag    = handleDrag;
	  item.ondragend = handleDrop;
	}
	function handleDrag(item)
	{
	  const selectedItem = item.target,
	        list = selectedItem.parentNode,
	        x = event.clientX,
	        y = event.clientY;
	  
	  selectedItem.classList.add('drag-sort-active');
	  let swapItem = document.elementFromPoint(x, y) === null ? selectedItem : document.elementFromPoint(x, y);
	  
	  if (list === swapItem.parentNode) {
	    swapItem = swapItem !== selectedItem.nextSibling ? swapItem : swapItem.nextSibling;
	    list.insertBefore(selectedItem, swapItem);
	  }
	}
	function handleDrop(item) {
	  item.target.classList.remove('drag-sort-active');
	  let dragSortEnable         = document.querySelector(".drag-sort-enable"),
	      dragSortEnableChildren = dragSortEnable.children,
	      i                      = 0;
	  for(i; i<dragSortEnableChildren.length; i++){
	    dragSortEnableChildren[i].setAttribute('data-position', i);
	  }
	  /*update database position for aside menu item start*/
	  update_position();
	  /*update database position for aside menu item end*/
	}
	(()=> {enableDragSort('drag-sort-enable')})();
	// update aside menu position start
	async function update_position()
	{
		let myLoader = document.querySelector('.loader');
		var id_position = {};
		var slider_item = document.querySelectorAll('.slider_item');
		myLoader.classList.add('active');
		slider_item = Array.isArray(slider_item) ? slider_item : Object.values(slider_item);
		slider_item.forEach(function(single_slider_item){
			id_position[single_slider_item.dataset.id] = single_slider_item.dataset.position;
			id_position[single_slider_item.dataset.id] = single_slider_item.dataset.position;
		});
		let url = "{{ route('admin.goal.sort_goal') }}";
		
		id_position = JSON.stringify(id_position);
		
		
		let res  = await fetch(url+"/"+id_position);
		let data = await res.text();
		
		myLoader.classList.remove('active');
	}
	// update aside menu position end
</script>
@endsection