<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Backend\UserController;
use App\Http\Controllers\Backend\CarController;
use App\Http\Controllers\Backend\ReportController;
use App\Http\Controllers\Backend\MemberController;
use App\Http\Controllers\Backend\SliderController;
use App\Http\Controllers\Backend\NewsLetterController;
use App\Http\Controllers\Backend\GoalPurposeController;
use App\Http\Controllers\Backend\CareerController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
Route::group(['prefix'=>'admin'], function()
{
	// NEWS LETTER MODULE
	Route::group(['prefix'=>'news-letter'], function(){
		Route::get('add', [NewsLetterController::class, 'create'])->name('admin.newsletter.add');
		Route::post('store', [NewsLetterController::class, 'store'])->name('admin.newsletter.store');
		Route::get('all', [NewsLetterController::class, 'index'])->name('admin.newsletter.all');
		Route::get('edit/{id}', [NewsLetterController::class, 'edit'])->name('admin.newsletter.edit');
		Route::post('update/{id}', [NewsLetterController::class, 'update'])->name('admin.newsletter.update');
		Route::get('view/{id}', [NewsLetterController::class, 'view'])->name('admin.newsletter.view');
		Route::get('destroy/{id}', [NewsLetterController::class, 'destroy'])->name('admin.newsletter.destroy');
	});

	// MEMBER MODULE
	Route::group(['prefix'=>'member'], function(){
		Route::match(['GET', 'POST'], 'all', [MemberController::class, 'index'])->name('admin.member.all');
		Route::get('edit/{id}', [MemberController::class, 'edit'])->name('admin.member.edit');
		Route::post('update/{id}', [MemberController::class, 'update'])->name('admin.member.update');
		Route::get('profile/{id}', [MemberController::class, 'profile'])->name('admin.member.profile');
		Route::post('member-status-update/{member_id}', [MemberController::class, 'statusUpdate'])->name('admin.member.status.update');
	});

	// SLIDER MODULE
	Route::group(['prefix'=>'slider'], function(){
		Route::match(['POST', 'GET'],'all', [SliderController::class, 'index'])->name('admin.slider.all');
		Route::get('create', [SliderController::class, 'create'])->name('admin.slider.create');
		Route::post('store', [SliderController::class, 'store'])->name('admin.slider.store');
		Route::get('edit/{id?}', [SliderController::class, 'edit'])->name('admin.slider.edit');
		Route::post('update/{id?}', [SliderController::class, 'update'])->name('admin.slider.update');
		Route::get('delete/{id?}', [SliderController::class, 'destroy'])->name('admin.slider.delete');
		Route::get('/sort/{id_position?}', [SliderController::class, 'slider_sorting'])->name('admin.slider.sort_slider');
	});

	// USER MODULE
	Route::group(['prefix'=>'user'], function(){
		Route::match(['GET', 'POST'], '/all', [UserController::class, 'index'])->name('admin.user.all');
		Route::get('add', [UserController::class, 'create'])->name('admin.user.add');
		Route::post('store', [UserController::class, 'store'])->name('admin.user.store');
		Route::get('edit/{id}', [UserController::class, 'edit'])->name('admin.user.edit');
		Route::post('update/{id}', [UserController::class, 'update'])->name('admin.user.update');
		Route::get('destroy/{id}', [UserController::class, 'destroy'])->name('admin.user.delete');
		Route::get('trash/{id}', [UserController::class, 'trash'])->name('admin.user.trash');
		Route::get('profile/{id}', [UserController::class, 'profile'])->name('admin.user.profile');
	});

	// ADMIN MENU PARMISSION MODULE
	Route::group(['prefix'=>'privilege'], function(){
		Route::get('/', [App\Http\Controllers\Backend\PrivilegeController::class, 'index'])->name('admin.privilege');
	});

	// USER PROFILE
	Route::group(['prefix'=>'profile'], function(){
		Route::get('/', [App\Http\Controllers\Backend\AdminController::class, 'profile'])->name('admin.profile');
		Route::post('/update', [App\Http\Controllers\Backend\AdminController::class, 'update'])->name('admin.profile.update');
	});

	// CAREER MODULE
	Route::group(['prefix'=>'career'], function(){
		Route::match(['POST', 'GET'],'all', [CareerController::class, 'index'])->name('admin.career.all');
		Route::get('add', [CareerController::class, 'create'])->name('admin.career.add');
		Route::post('store', [CareerController::class, 'store'])->name('admin.career.store');
		Route::get('edit/{id?}', [CareerController::class, 'edit'])->name('admin.career.edit');
		Route::post('update/{id}', [CareerController::class, 'update'])->name('admin.career.update');
		Route::get('delete/{id?}', [CareerController::class, 'destroy'])->name('admin.career.delete');
		Route::match(['POST', 'GET'],'trash-list', [CareerController::class, 'trashList'])->name('admin.career.trash_list');
	});


	// 
	Route::group(['prefix'=>'goal'], function(){
		Route::match(['POST', 'GET'],'all', [GoalPurposeController::class, 'index'])->name('admin.goal.all');
		Route::get('add', [GoalPurposeController::class, 'create'])->name('admin.goal.add');
		Route::post('store', [GoalPurposeController::class, 'store'])->name('admin.goal.store');
		Route::get('edit/{id?}', [GoalPurposeController::class, 'edit'])->name('admin.goal.edit');
		Route::post('update/{id}', [GoalPurposeController::class, 'update'])->name('admin.goal.update');
		Route::get('to-trash/{id?}', [GoalPurposeController::class, 'toTrash'])->name('admin.goal.totrash');
		Route::get('back-to-trash/{id?}', [GoalPurposeController::class, 'backToTrash'])->name('admin.goal.back_to_trash');
		Route::match(['POST', 'GET'],'trash-list', [GoalPurposeController::class, 'trashList'])->name('admin.goal.trash_list');;
		Route::match(['POST', 'GET'], 'sort_goal/{slug?}', [GoalPurposeController::class, 'SortGoal'])->name('admin.goal.sort_goal');;
	});

	// ADMIN LOGIN
	Route::get('login', [App\Http\Controllers\Backend\Auth\LoginController::class, 'showLoginForm'])->name('admin.login');
	Route::post('login', [App\Http\Controllers\Backend\Auth\LoginController::class, 'login'])->name('admin.login');
	Route::match(['GET', 'POST'], 'logout', [App\Http\Controllers\Backend\Auth\LoginController::class, 'logout'])->name('admin.logout');
	Route::match(['GET', 'POST'], 'settings', [App\Http\Controllers\Backend\SettingsController::class, 'index'])->name('admin.settings');
	// DASHBOARD
	Route::get('dashboard', [App\Http\Controllers\Backend\HomeController::class, 'index'])->name('admin.dashboard');
});

// Default Routes
Auth::routes(['login'=>false]);

// Fontend Routes
include('fontend.php');